@@ -24,11 +24,13 @@ if PY2:
     text_type = unicode
     builtins_open = '__builtin__.open'
     from urlparse import urlparse
+    from StringIO import StringIO
 else:
     text_type = str
     builtins_open = 'builtins.open'
     from urllib.parse import urlparse
+    from io import StringIO
 
 __all__ = [
-    'PY2', 'text_type', 'urlparse'
+    'PY2', 'text_type', 'urlparse', 'StringIO'
 ]
